@@ -2,8 +2,10 @@ from xstatic.main import XStatic
 
 # names below must be package names
 mod_names = [
+    'asciinema_player',
     'bootbox',
     'bootstrap',
+    'font_awesome',
     'jquery',
     'jquery_ui',
     'jquery_file_upload',
